*********************************************************************
:mod:`mopidy.outputs.gstreamer` -- GStreamer output for all platforms
*********************************************************************

.. inheritance-diagram:: mopidy.outputs.gstreamer

.. automodule:: mopidy.outputs.gstreamer
    :synopsis: GStreamer output for all platforms
    :members:
